@@ -8,12 +8,12 @@ from nltk.util import ngrams
 from nltk.util import bigrams as bi
 from nltk.util import trigrams as tri
 
-
 from .preprocess import *
-from .clean_numbers import remove_numbers
-from .stopwords import remove_stopwords
+from .clean_numbers import *
+from .stopwords import *
 from .group import grouper
 from .clean_ngram import *
+import sys
 
 
 def arabica_freq(text: str,                 # Text
@@ -24,7 +24,6 @@ def arabica_freq(text: str,                 # Text
                  time_freq: str = '',       # Aggregation period: 'Y'/'M'/'D', if no aggregation: 'ungroup'
                  max_words: int = '',       # Max number for most frequent n-grams displayed for each period
                  numbers: bool = False,     # Remove all digits
-                 punct: bool = False,       # Remove all punctuation
                  lower_case: bool = False   # Lowercase text before cleaning and frequency analysis
                  ):
 
@@ -44,22 +43,52 @@ def arabica_freq(text: str,                 # Text
         data['time']=data['time'].astype(str)
         data['time'] = pd.to_datetime(data['time'], dayfirst=False)
 
+    else:
+        sys.exit('Incorrect value for date_format parameter. Allowed: "us", "eur"')
+
+    # cleaning - blank rows
     data=data.set_index(data['time'])
     data.replace("", float("NaN"), inplace=True)
     data.dropna(subset = ["text"], inplace=True)
 
-    if lower_case is True:
-        data['text'] = np.vectorize(lower_casing)(data['text'])
+    # cleaning - unwanted strings
+    if skip is not None:
+        data['text'] = data.text.str.replace('|'.join(skip), '.', regex=True).str.strip()
 
-    if punct is True:
-        data['text'] = np.vectorize(preprocess)(data['text'])
+    # cleaning - futher processing
+    data['text'] = data['text'].str.replace("."," . ")
+    data['text'] = data['text'].str.replace("!"," ! ")
+    data['text'] = data['text'].str.replace("?"," ? ")
+    data['text'] = data['text'].str.replace("."," . ")
+    data['text'] = data['text'].str.replace(","," , ")
+    data['text'] = data['text'].str.replace("#"," # ")
 
+    # cleaning - stop words
+    data.replace("", float("NaN"), inplace=True)
+    data.dropna(subset = ["text"], inplace=True)
     if stopwords is not None:
         data['text'] = data.text.map(lambda x: remove_stopwords(x,stopwords=[stopwords]))
 
+    # cleaning - punctuation
+    data.replace("", float("NaN"), inplace=True)
+    data.dropna(subset = ["text"], inplace=True)
+    data['text'] = np.vectorize(preprocess)(data['text'])
+
+
+    # cleaning - numbers
+    data.replace("", float("NaN"), inplace=True)
+    data.dropna(subset = ["text"], inplace=True)
     if numbers is True:
         data['text'] = np.vectorize(remove_numbers)(data['text'])
 
+
+    # cleaning - lowercasing
+    data.replace("", float("NaN"), inplace=True)
+    data.dropna(subset = ["text"], inplace=True)
+    if lower_case is True:
+        data['text'] = np.vectorize(lower_casing)(data['text'])
+
+
     periods = []
     unigrams_freq = []
     bigrams_freq = []
@@ -70,12 +99,9 @@ def arabica_freq(text: str,                 # Text
         periods.append(period)
         word = row[0]
         token = str(word).split()
-        if skip is not None:
-            tokens_clean = [x for x in token if x not in skip]
-        else: tokens_clean = token
-        unigrams = list(ngrams(tokens_clean, 1))
-        bigrams = list(bi(tokens_clean))
-        trigrams = list(tri(tokens_clean))
+        unigrams = list(ngrams(token, 1))
+        bigrams = list(bi(token))
+        trigrams = list(tri(token))
         unigrams_freq.append(unigrams)
         bigrams_freq.append(bigrams)
         trigrams_freq.append(trigrams)
@@ -103,16 +129,17 @@ def arabica_freq(text: str,                 # Text
         unigram_ungr['freq'] = unigram_ungr.iloc[:,[0]]
         unigram_ungr = unigram_ungr.sort_values(by='freq', ascending=False)
         unigram_ungr['unigram'] = unigram_ungr['word'].astype(str) + ": " + unigram_ungr['freq'].astype(str)
-        unigram_ungr['unigram'] = unigram_ungr['unigram'].str.replace(',', '')
+        unigram_ungr['unigram'] = unigram_ungr['unigram'].str.replace(',', '', regex = True)
         unigram_ungr = unigram_ungr['unigram']
         unigram_ungr = unigram_ungr.iloc[:max_words]
         unigram_ungr= unigram_ungr.astype(str)
-        unigram_ungr = unigram_ungr.str.replace('(', '')
-        unigram_ungr = unigram_ungr.str.replace(')', '')
+        unigram_ungr = unigram_ungr.str.replace('''(''', '')
+        unigram_ungr = unigram_ungr.str.replace(''')''', '')
         unigram_ungr = unigram_ungr.str.replace("""'""", '')
         unigram_ungr = unigram_ungr.str.split(n = 2, pat=':',expand=True)
         unigram_ungr['unigram_freq'] = unigram_ungr.iloc[:,[1]]
         unigram_ungr['unigram'] = unigram_ungr.iloc[:,[0]]
+        unigram_ungr['unigram'] = unigram_ungr['unigram'].astype("str")
         unigram_ungr = unigram_ungr[['unigram','unigram_freq']]
         unigram_ungr.reset_index(inplace = True)
 
@@ -134,7 +161,7 @@ def arabica_freq(text: str,                 # Text
         bigram_ungr['bigram_freq'] = bigram_ungr.iloc[:,[0]]
         bigram_ungr = bigram_ungr.sort_values(by='bigram_freq', ascending=False)
         bigram_ungr['bigram'] = bigram_ungr['bigram'].astype(str) + ": " + bigram_ungr['bigram_freq'].astype(str)
-        bigram_ungr['bigram'] = bigram_ungr['bigram'].str.replace(',', '')
+        bigram_ungr['bigram'] = bigram_ungr['bigram'].str.replace(',', '', regex = True)
         bigram_ungr = bigram_ungr['bigram']
         bigram_ungr = bigram_ungr.iloc[:max_words]
         bigram_ungr= bigram_ungr.astype(str)
@@ -154,7 +181,6 @@ def arabica_freq(text: str,                 # Text
         bigram_freq = bigram_ungr['bigram_freq']
         bigram_ungr = pd.merge(bigram_col, bigram_freq, left_index=True, right_index=True)
 
-
         df['trigrams'] = df['trigrams'].astype(str)
         df['trigrams']= df['trigrams'].str.replace(")"," ")
         df['trigrams']= df['trigrams'].str.replace("(",' ')
@@ -195,7 +221,7 @@ def arabica_freq(text: str,                 # Text
         freq_final = unigram_ungr.merge(bigram_ungr, how='left',left_index=True, right_index=True)
         freq_final = freq_final.merge(trigram_ungr, how='left',left_index=True, right_index=True)
         freq_final = freq_final[['unigram','unigram_freq','bigram','bigram_freq','trigram','trigram_freq']]
-        freq_final = pd.DataFrame(freq_final)
+        freq_final = pd.DataFrame(freq_final, index= None)
 
     else:
 
@@ -219,7 +245,7 @@ def arabica_freq(text: str,                 # Text
         freq_final['unigram'] = np.vectorize(final_cleaning)(freq_final['unigram'])
         freq_final['bigram'] = np.vectorize(final_cleaning)(freq_final['bigram'])
         freq_final['trigram'] = np.vectorize(final_cleaning)(freq_final['trigram'])
-        freq_final = freq_final[freq_final['unigram']!=': 1']
+        freq_final = freq_final[freq_final['unigram']!=': 1'].astype('str')
         freq_final = freq_final[freq_final['bigram']!=': 1']
         freq_final = freq_final[freq_final['trigram']!=': 1']
 
@@ -234,5 +260,5 @@ def arabica_freq(text: str,                 # Text
         elif time_freq == 'D':
             freq_final['period'] = pd.to_datetime(freq_final['period'].astype('str'))
             freq_final['period'] = freq_final['period'].dt.strftime('%Y-%m-%d')
-    #
+
     return freq_final
\ No newline at end of file
