@@ -7,33 +7,34 @@ import matplotlib.pyplot as plt
 from matplotlib.pyplot import figure
 import pandas as pd
 import numpy as np
+import sys
+
+import nltk
+nltk.download('stopwords')
 
 
+def cappuccino(text: str,                  # Text
+               time: str,                  # Time
+               date_format: str,           # Date format: 'eur' - European, 'us' - American
+               stopwords: [],              # Languages for stop words
+               skip: [ ],                  # Remove additional strings
+               plot: str = '',             # Chart type: 'wordcloud'/'heatmap'/'line'
+               ngram: int = '',            # N-gram size, 1 = unigram, 2 = bigram, 3 = trigram
+               time_freq: str = '',        # Aggregation period: 'Y'/'M', if no aggregation: 'ungroup'
+               max_words: int = '',        # Max number for most frequent n-grams displayed for each period
+               numbers: bool = False,      # Remove numbers
+               lower_case: bool = False):  # Lowercase text before cleaning and frequency analysis
 
-def cappuccino(text,
-               time,
-               date_format,
-               plot,
-               ngram,
-               time_freq,
-               max_words,
-               stopwords,
-               skip,
-               numbers,
-               punct,
-               lower_case):
 
-    result = arabica_freq(text=text,
-                          time=time,
+    result = arabica_freq(text = text,
+                          time = time,
                           date_format = date_format,
-                          time_freq=time_freq,
-                          max_words=max_words,
-                          stopwords=stopwords,
-                          skip=skip,
-                          numbers=numbers,
-                          punct=punct,
-                          lower_case=lower_case)
-
+                          time_freq = time_freq,
+                          max_words = max_words,
+                          stopwords = stopwords,
+                          skip = skip,
+                          numbers = numbers,
+                          lower_case = lower_case)
 
     if ngram == 1:
         if time_freq == 'ungroup':
@@ -55,6 +56,9 @@ def cappuccino(text,
                 plt.axis('off')
                 picture = plt.show()
 
+            else:
+                sys.exit('Incorrect value for plot parameter. Allowed: "wordcloud"')
+
 
         elif time_freq == 'M':
             period = result['period']
@@ -100,13 +104,13 @@ def cappuccino(text,
                                axis_title_y=element_text(colour="black"),
                                axis_text_x=element_text(colour = "black", rotation=45, hjust=1),
                                figure_size=(10, 5),
-                               panel_grid_major = element_blank(),
+                               panel_grid_major = element_line(color='black',size = 0.1),
                                panel_background = element_rect(colour = "white", fill = "white"),
                                plot_background = element_rect(colour = 'white',fill = "white"))
                        ).draw(show=False, return_ggplot=True)
 
 
-                plt.gcf().set_dpi(500)
+                plt.gcf().set_dpi(800)
                 picture = plt.show()
 
 
@@ -144,9 +148,12 @@ def cappuccino(text,
                        ).draw(show=False, return_ggplot=True)
 
 
-                plt.gcf().set_dpi(500)
+                plt.gcf().set_dpi(800)
                 picture = plt.show()
 
+            else:
+                sys.exit('Incorrect value for plot parameter. Allowed: "heatmap", "line"')
+
 
         elif time_freq == 'Y':
             period = result['period']
@@ -192,12 +199,12 @@ def cappuccino(text,
                                axis_title_y=element_text(colour="black"),
                                axis_text_x=element_text(colour = "black", rotation=45, hjust='1'),
                                figure_size=(10, 6),
-                               panel_grid_major = element_blank(),
+                               panel_grid_major = element_line(color='black',size = 0.1),
                                panel_background = element_rect(colour = "white", fill = "white"),
                                plot_background = element_rect(colour = 'white',fill = "white"))
                        ).draw(show=False, return_ggplot=True)
 
-                plt.gcf().set_dpi(500)
+                plt.gcf().set_dpi(800)
                 picture = plt.show()
 
             elif plot == 'line':
@@ -234,9 +241,15 @@ def cappuccino(text,
                        ).draw(show=False, return_ggplot=True)
 
 
-                plt.gcf().set_dpi(500)
+                plt.gcf().set_dpi(800)
                 picture = plt.show()
 
+            else:
+                sys.exit('Incorrect value for plot parameter. Allowed: "heatmap", "line"')
+
+        else:
+            sys.exit('Incorrect value for time_freq parameter. Allowed: "ungroup", "Y", "M"')
+
     elif ngram == 2:
         if time_freq == 'ungroup':
             if plot == 'wordcloud':
@@ -258,6 +271,9 @@ def cappuccino(text,
                 plt.axis('off')
                 picture = plt.show()
 
+            else:
+                sys.exit('Incorrect value for plot parameter. Allowed: "wordcloud"')
+
         elif time_freq == 'M':
             period = result['period']
             subset = result['bigram']
@@ -301,13 +317,13 @@ def cappuccino(text,
                                axis_title_y=element_text(colour="black"),
                                axis_text_x=element_text(colour = "black", rotation=45, hjust=1),
                                figure_size=(10, 8),
-                               panel_grid_major = element_blank(),
+                               panel_grid_major = element_line(color='black',size = 0.1),
                                panel_background = element_rect(colour = "white", fill = "white"),
                                plot_background = element_rect(colour = 'white',fill = "white"))
                        ).draw(show=False, return_ggplot=True)
 
 
-                plt.gcf().set_dpi(500)
+                plt.gcf().set_dpi(800)
                 picture = plt.show()
 
 
@@ -345,9 +361,13 @@ def cappuccino(text,
                                plot_background = element_rect(colour = 'white',fill = "white"))
                        ).draw(show=False, return_ggplot=True)
 
-                plt.gcf().set_dpi(500)
+                plt.gcf().set_dpi(800)
                 picture = plt.show()
 
+            else:
+                sys.exit('Incorrect value for plot parameter. Allowed: "heatmap", "line"')
+
+
         elif time_freq == 'Y':
             period = result['period']
             subset = result['bigram']
@@ -391,13 +411,13 @@ def cappuccino(text,
                                axis_title_y=element_text(colour="black"),
                                axis_text_x=element_text(colour = "black", rotation=45, hjust=1),
                                figure_size=(10, 8),
-                               panel_grid_major = element_blank(),
+                               panel_grid_major = element_line(color='black',size = 0.1),
                                panel_background = element_rect(colour = "white", fill = "white"),
                                plot_background = element_rect(colour = 'white',fill = "white"))
                        ).draw(show=False, return_ggplot=True)
 
 
-                plt.gcf().set_dpi(500)
+                plt.gcf().set_dpi(800)
                 picture = plt.show()
 
 
@@ -435,10 +455,16 @@ def cappuccino(text,
                                plot_background = element_rect(colour = 'white',fill = "white"))
                        ).draw(show=False, return_ggplot=True)
 
-                plt.gcf().set_dpi(500)
+                plt.gcf().set_dpi(800)
                 picture = plt.show()
 
 
+            else:
+                sys.exit('Incorrect value for plot parameter. Allowed: "heatmap", "line"')
+
+        else:
+            sys.exit('Incorrect value for time_freq parameter. Allowed: "ungroup", "Y", "M"')
+
     elif ngram == 3:
         if time_freq == 'ungroup':
             if plot == 'wordcloud':
@@ -460,5 +486,13 @@ def cappuccino(text,
                 plt.axis('off')
                 picture = plt.show()
 
+            else:
+                sys.exit('Incorrect value for plot parameter. Allowed: "wordcloud"')
+
+        else:
+            sys.exit('Incorrect value for time_freq parameter. Allowed: "ungroup"')
+
+    else:
+        sys.exit("Incorrect value for ngram parameter. Allowed: 1,2,3.")
 
     return picture
\ No newline at end of file
